==> materials-design-0.0.12.tgz: package/lowcode_es/meta.js <==
import _extends from "@babel/runtime/helpers/extends";
import DataAddDialogMeta from "./data-add-dialog/meta";
import DataEditDialogMeta from "./data-edit-dialog/meta";
import GroupMeta from "./group/meta";
import PreviewListMeta from "./preview-list/meta";
import TableGoodsInfoMeta from "./table-goods-info/meta";
import TableInfoMeta from "./table-info/meta";
import TableMultipleMeta from "./table-multiple/meta";
import TableOperatesMeta from "./table-operates/meta";
import TablePersonMeta from "./table-person/meta";
import TableStatusMeta from "./table-status/meta";
import TableTagsMeta from "./table-tags/meta";
import TableTextMeta from "./table-text/meta";
import YwButtonMeta from "./yw-button/meta";
import YwContainerMeta from "./yw-container/meta";
import YwDetailInfoMeta from "./yw-detail-info/meta";
import YwDrawerSelectorMeta from "./yw-drawer-selector/meta";
import YwEmpSelectorMeta from "./yw-emp-selector/meta";
import YwFilterMeta from "./yw-filter/meta";
import YwFormDialogMeta from "./yw-form-dialog/meta";
import YwFormTableMeta from "./yw-form-table/meta";
import YwIconMeta from "./yw-icon/meta";
import YwImageMeta from "./yw-image/meta";
import YwJsonFormMeta from "./yw-json-form/meta";
import YwTabMeta from "./yw-tab/meta";
import YwTableDialogMeta from "./yw-table-dialog/meta";
import YwTableMeta from "./yw-table/meta";
import YwTagMeta from "./yw-tag/meta";
import YwTitleMeta from "./yw-title/meta";
import YwUploadMeta from "./yw-upload/meta";
var componentCategorySort = {};
["通用", "业务区块"].reverse().forEach(function (item, index) {
  componentCategorySort[item] = ++index;
});
function generateComponentList(components) {
  var componentList = [{
    title: '常用',
    icon: '',
    children: []
  }, {
    title: '容器',
    icon: '',
    children: []
  }, {
    title: '导航',
    icon: '',
    children: []
  }, {
    title: '内容',
    icon: '',
    children: []
  }, {
    title: 'Feedback 反馈',
    icon: '',
    children: []
  }];
  var groupMap = {
    原子组件: true
  };
  var compGroup = {};
  components.forEach(function (comp) {
    var category = comp.category || '其他';
    if (comp.group && !compGroup[comp.componentName]) {
      compGroup[comp.componentName] = comp.group;
    }
    if (comp.group && !groupMap[comp.group]) {
      groupMap[comp.group] = true;
    }
    var target = componentList.find(function (item) {
      return item.title === category;
    });
    if (!target) {
      target = {
        title: category,
        icon: '',
        children: []
      };
      componentList.push(target);
    }
    if (comp.snippets && comp.snippets.length) {
      target.children.push({
        componentName: comp.componentName,
        title: comp.title || comp.componentName,
        sort: {
          category: target.title,
          group: compGroup[comp.componentName] || '原子组件',
          priority: componentCategorySort[target.title] || 0
        },
        icon: '',
        "package": comp.npm.pkg,
        snippets: comp.snippets || []
      });
    }
  });
  return componentList;
}
function fillRealVersion(meta, packageName, version, basicLibraryVersion) {
  if (packageName === void 0) {
    packageName = '@ywfe/materials-design';
  }
  if (version === void 0) {
    version = '0.0.12';
  }
  if (basicLibraryVersion === void 0) {
    basicLibraryVersion = {
      "@alifd/next": "1.25.23",
      "@alifd/meet": "2.6.3",
      "antd": "4.17.3"
    };
  }
  if (!meta || !version) {
    return meta;
  }
  var npm = meta.npm;
  if (!npm) {
    return meta;
  }
  if (typeof basicLibraryVersion === 'object' && basicLibraryVersion[npm["package"]]) {
    meta.npm = _extends({}, npm, {
      version: basicLibraryVersion[npm["package"]]
    });
  } else if (npm["package"] === packageName) {
    meta.npm = _extends({}, npm, {
      version: version
    });
  }
  return meta;
}
var componentMetas = [DataAddDialogMeta, DataEditDialogMeta, GroupMeta, PreviewListMeta, TableGoodsInfoMeta, TableInfoMeta, TableMultipleMeta, TableOperatesMeta, TablePersonMeta, TableStatusMeta, TableTagsMeta, TableTextMeta, YwButtonMeta, YwContainerMeta, YwDetailInfoMeta, YwDrawerSelectorMeta, YwEmpSelectorMeta, YwFilterMeta, YwFormDialogMeta, YwFormTableMeta, YwIconMeta, YwImageMeta, YwJsonFormMeta, YwTabMeta, YwTableDialogMeta, YwTableMeta, YwTagMeta, YwTitleMeta, YwUploadMeta];
var components = [];
var npmInfo = {
  "package": "@ywfe/materials-design",
  "version": "0.0.12"
};
componentMetas.forEach(function (meta) {
  if (Array.isArray(meta)) {
    components.push.apply(components, meta.map(function (item) {
      if (!item.npm) {
        var componentName = item.componentName;
        var names = componentName.split('.');
        var exportName = names[0],
          subName = names[1];
        item.npm = {
          exportName: exportName,
          main: '',
          destructuring: true,
          subName: names.length > 1 ? componentName.slice(componentName.indexOf('.') + 1) : subName
        };
      }
      item.npm = _extends({}, npmInfo, item.npm || {});
      return fillRealVersion(item);
    }));
  } else if (meta.components) {
    components.push.apply(components, meta.components.map(function (item) {
      if (!item.npm) {
        var componentName = item.componentName;
        var names = componentName.split('.');
        var exportName = names[0],
          subName = names[1];
        item.npm = {
          exportName: exportName,
          main: '',
          destructuring: true,
          subName: names.length > 1 ? componentName.slice(componentName.indexOf('.') + 1) : subName
        };
      }
      item.npm = _extends({}, npmInfo, item.npm || {});
      return fillRealVersion(item);
    }));
  } else {
    if (!meta.npm) {
      var componentName = meta.componentName;
      var names = componentName.split('.');
      var exportName = names[0],
        subName = names[1];
      meta.npm = {
        exportName: exportName,
        main: '',
        destructuring: true,
        subName: names.length > 1 ? componentName.slice(componentName.indexOf('.') + 1) : subName
      };
    }
    meta.npm = _extends({}, npmInfo, meta.npm || {});
    components.push(fillRealVersion(meta));
  }
});
var componentList = generateComponentList(components);
export { components, componentList };
var execCompile = !!true;
if (!execCompile) {
  window.YwfeMaterialsDesignMeta = {
    components: components,
    componentList: componentList
  };
}

==> materials-design-0.0.26.tgz: package/lowcode_es/meta.js <==
import _extends from "@babel/runtime/helpers/extends";
import DataAddDialogMeta from "./data-add-dialog/meta";
import DataEditDialogMeta from "./data-edit-dialog/meta";
import GroupMeta from "./group/meta";
import PreviewListMeta from "./preview-list/meta";
import TableGoodsInfoMeta from "./table-goods-info/meta";
import TableInfoMeta from "./table-info/meta";
import TableMultipleMeta from "./table-multiple/meta";
import TableOperatesMeta from "./table-operates/meta";
import TablePersonMeta from "./table-person/meta";
import TableStatusMeta from "./table-status/meta";
import TableTagsMeta from "./table-tags/meta";
import TableTextMeta from "./table-text/meta";
import YwButtonMeta from "./yw-button/meta";
import YwCategorySelectMeta from "./yw-category-select/meta";
import YwContainerMeta from "./yw-container/meta";
import YwDetailInfoMeta from "./yw-detail-info/meta";
import YwDrawerSelectorMeta from "./yw-drawer-selector/meta";
import YwEmpSelectorMeta from "./yw-emp-selector/meta";
import YwExportMeta from "./yw-export/meta";
import YwFilterMeta from "./yw-filter/meta";
import YwFormDialogMeta from "./yw-form-dialog/meta";
import YwFormTableMeta from "./yw-form-table/meta";
import YwIconMeta from "./yw-icon/meta";
import YwImageMeta from "./yw-image/meta";
import YwJsonFormMeta from "./yw-json-form/meta";
import YwMemberListMeta from "./yw-member-list/meta";
import YwPlatformIconMeta from "./yw-platform-icon/meta";
import YwTabMeta from "./yw-tab/meta";
import YwTableDialogMeta from "./yw-table-dialog/meta";
import YwTableMeta from "./yw-table/meta";
import YwTagMeta from "./yw-tag/meta";
import YwTitleMeta from "./yw-title/meta";
import YwUploadMeta from "./yw-upload/meta";
import YwUserSelectorMeta from "./yw-user-selector/meta";
var componentCategorySort = {};
["通用", "业务区块"].reverse().forEach(function (item, index) {
  componentCategorySort[item] = ++index;
});
function generateComponentList(components) {
  var componentList = [{
    title: '常用',
    icon: '',
    children: []
  }, {
    title: '容器',
    icon: '',
    children: []
  }, {
    title: '导航',
    icon: '',
    children: []
  }, {
    title: '内容',
    icon: '',
    children: []
  }, {
    title: 'Feedback 反馈',
    icon: '',
    children: []
  }];
  var groupMap = {
    原子组件: true
  };
  var compGroup = {};
  components.forEach(function (comp) {
    var category = comp.category || '其他';
    if (comp.group && !compGroup[comp.componentName]) {
      compGroup[comp.componentName] = comp.group;
    }
    if (comp.group && !groupMap[comp.group]) {
      groupMap[comp.group] = true;
    }
    var target = componentList.find(function (item) {
      return item.title === category;
    });
    if (!target) {
      target = {
        title: category,
        icon: '',
        children: []
      };
      componentList.push(target);
    }
    if (comp.snippets && comp.snippets.length) {
      target.children.push({
        componentName: comp.componentName,
        title: comp.title || comp.componentName,
        sort: {
          category: target.title,
          group: compGroup[comp.componentName] || '原子组件',
          priority: componentCategorySort[target.title] || 0
        },
        icon: '',
        "package": comp.npm.pkg,
        snippets: comp.snippets || []
      });
    }
  });
  return componentList;
}
function fillRealVersion(meta, packageName, version, basicLibraryVersion) {
  if (packageName === void 0) {
    packageName = '@ywfe/materials-design';
  }
  if (version === void 0) {
    version = '0.0.26';
  }
  if (basicLibraryVersion === void 0) {
    basicLibraryVersion = {
      "@alifd/next": "1.25.23",
      "@alifd/meet": "2.6.3",
      "antd": "4.17.3"
    };
  }
  if (!meta || !version) {
    return meta;
  }
  var npm = meta.npm;
  if (!npm) {
    return meta;
  }
  if (typeof basicLibraryVersion === 'object' && basicLibraryVersion[npm["package"]]) {
    meta.npm = _extends({}, npm, {
      version: basicLibraryVersion[npm["package"]]
    });
  } else if (npm["package"] === packageName) {
    meta.npm = _extends({}, npm, {
      version: version
    });
  }
  return meta;
}
var componentMetas = [DataAddDialogMeta, DataEditDialogMeta, GroupMeta, PreviewListMeta, TableGoodsInfoMeta, TableInfoMeta, TableMultipleMeta, TableOperatesMeta, TablePersonMeta, TableStatusMeta, TableTagsMeta, TableTextMeta, YwButtonMeta, YwCategorySelectMeta, YwContainerMeta, YwDetailInfoMeta, YwDrawerSelectorMeta, YwEmpSelectorMeta, YwExportMeta, YwFilterMeta, YwFormDialogMeta, YwFormTableMeta, YwIconMeta, YwImageMeta, YwJsonFormMeta, YwMemberListMeta, YwPlatformIconMeta, YwTabMeta, YwTableDialogMeta, YwTableMeta, YwTagMeta, YwTitleMeta, YwUploadMeta, YwUserSelectorMeta];
var components = [];
var npmInfo = {
  "package": "@ywfe/materials-design",
  "version": "0.0.26"
};
componentMetas.forEach(function (meta) {
  if (Array.isArray(meta)) {
    components.push.apply(components, meta.map(function (item) {
      if (!item.npm) {
        var componentName = item.componentName;
        var names = componentName.split('.');
        var exportName = names[0],
          subName = names[1];
        item.npm = {
          exportName: exportName,
          main: '',
          destructuring: true,
          subName: names.length > 1 ? componentName.slice(componentName.indexOf('.') + 1) : subName
        };
      }
      item.npm = _extends({}, npmInfo, item.npm || {});
      return fillRealVersion(item);
    }));
  } else if (meta.components) {
    components.push.apply(components, meta.components.map(function (item) {
      if (!item.npm) {
        var componentName = item.componentName;
        var names = componentName.split('.');
        var exportName = names[0],
          subName = names[1];
        item.npm = {
          exportName: exportName,
          main: '',
          destructuring: true,
          subName: names.length > 1 ? componentName.slice(componentName.indexOf('.') + 1) : subName
        };
      }
      item.npm = _extends({}, npmInfo, item.npm || {});
      return fillRealVersion(item);
    }));
  } else {
    if (!meta.npm) {
      var componentName = meta.componentName;
      var names = componentName.split('.');
      var exportName = names[0],
        subName = names[1];
      meta.npm = {
        exportName: exportName,
        main: '',
        destructuring: true,
        subName: names.length > 1 ? componentName.slice(componentName.indexOf('.') + 1) : subName
      };
    }
    meta.npm = _extends({}, npmInfo, meta.npm || {});
    components.push(fillRealVersion(meta));
  }
});
var componentList = generateComponentList(components);
export { components, componentList };
var execCompile = !!true;
if (!execCompile) {
  window.YwfeMaterialsDesignMeta = {
    components: components,
    componentList: componentList
  };
}
